"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callCloudFnMethod = void 0;
const vm2_1 = require("vm2");
const error_1 = require("../error");
async function callCloudFnMethod(params, context) {
    try {
        const vm = new vm2_1.NodeVM({
            sandbox: { TCBError: error_1.TCBError },
            require: {
                // 允许引用所有外部包, 如 request, @cloudbase/node-sdk
                external: true,
                // 允许引用所有内置模块, 如 fs, path
                builtin: ['*'],
            },
            // 复制环境变量, 保留引用, 这样下边这种方式才会生效
            //  允许用户通过 process.env['NODE_TLS_REJECT_UNAUTHORIZED'] = 0 来规避请求部分网站可能出现的证书问题
            env: process.env,
        });
        const vmFn = vm.run(params.methodCfg.calleeBody.callee, `${params.methodName}.js`);
        const result = await vmFn(params.params, context);
        return result;
    }
    catch (e) {
        let code = 'FnError.Cloud';
        if (e.name)
            code += `.${e.code || e.name}`;
        throw new error_1.TCBError(code, `数据源自定义方法调用失败: ${e.message}`, {
            original: e,
        });
    }
}
exports.callCloudFnMethod = callCloudFnMethod;
